@@ -26,55 +26,95 @@
 #include <gtk/gtkobject.h>
 #include <gtk/gtktypeutils.h>
 #include <gtk/gtkmarshal.h>
+#include <gtkmozembed.h>
 
-#define YELP_TYPE_HTML        (yelp_html_get_type ())
-#define YELP_HTML(o)          (GTK_CHECK_CAST ((o), YELP_TYPE_HTML, YelpHtml))
-#define YELP_HTML_CLASS(k)    (GTK_CHECK_FOR_CAST((k), YELP_TYPE_HTML, YelpHtmlClass))
-#define YELP_IS_HTML(o)       (GTK_CHECK_TYPE ((o), YELP_TYPE_HTML))
-#define YELP_IS_HTML_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), YELP_TYPE_HTML))
+#include "yelp-print.h"
+
+G_BEGIN_DECLS
+
+#define YELP_TYPE_HTML         (yelp_html_get_type ())
+#define YELP_HTML(o)           (GTK_CHECK_CAST ((o), YELP_TYPE_HTML, YelpHtml))
+#define YELP_HTML_CLASS(k)     (GTK_CHECK_FOR_CAST((k), YELP_TYPE_HTML, YelpHtmlClass))
+#define YELP_IS_HTML(o)        (GTK_CHECK_TYPE ((o), YELP_TYPE_HTML))
+#define YELP_IS_HTML_CLASS(k)  (GTK_CHECK_CLASS_TYPE ((k), YELP_TYPE_HTML))
+#define YELP_HTML_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), YELP_TYPE_HTML, YelpHtmlClass))
 
 typedef struct _YelpHtml        YelpHtml;
 typedef struct _YelpHtmlClass   YelpHtmlClass;
 typedef struct _YelpHtmlPriv    YelpHtmlPriv;
 
 struct _YelpHtml {
-	GObject       parent;
-	
+	GtkMozEmbed   parent;
+
 	YelpHtmlPriv *priv;
 };
 
 struct _YelpHtmlClass {
-        GObjectClass  parent_class;
+        GtkMozEmbedClass parent_class;
+
+	guint font_handler;
+	guint color_handler;
+	guint a11y_handler;
 
 	/* Signals */
 	void (*uri_selected)   (YelpHtml    *view,
-				YelpURI     *uri,
+				gchar       *uri,
 				gboolean     handled);
+	gboolean (*frame_selected) (YelpHtml    *view,
+				gchar       *uri,
+				gboolean    handled);
 	void (*title_changed)  (YelpHtml    *view,
 				const gchar *new_title);
+	void (*popupmenu_requested) (YelpHtml *view,
+				     const gchar *link);
+
 };
 
 GType           yelp_html_get_type       (void);
 YelpHtml *      yelp_html_new            (void);
 
 void            yelp_html_set_base_uri   (YelpHtml    *html,
-					  YelpURI     *uri);
-void            yelp_html_clear          (YelpHtml    *html);
+					  const gchar *uri);
+void            yelp_html_open_stream    (YelpHtml    *html,
+					  const gchar *mime);
 void            yelp_html_write          (YelpHtml    *html,
 					  const gchar *data,
 					  gint         len);
 void            yelp_html_printf         (YelpHtml    *html, 
 					  char        *format, 
-					  ...);
+					  ...) G_GNUC_PRINTF (2,3);
 void            yelp_html_close          (YelpHtml    *html);
 
-GtkWidget *     yelp_html_get_widget     (YelpHtml    *html);
+void            yelp_html_frames         (YelpHtml    *html,
+					  gboolean     enable);
 
 gboolean        yelp_html_find           (YelpHtml    *html,
-					  const gchar *str,
-					  gboolean     match_case,
-					  gboolean     wrap,
+					  const gchar *str);
+
+gboolean	yelp_html_find_again	 (YelpHtml    *html,					  
 					  gboolean     forward);
 
-#endif /* __YELP_HTML_H__ */
+void		yelp_html_set_find_props (YelpHtml    *html,
+					  const char  *str,
+					  gboolean     match_case,
+					  gboolean     wrap);
 
+void            yelp_html_jump_to_anchor (YelpHtml    *html,
+					  gchar       *anchor);
+
+void            yelp_html_copy_selection (YelpHtml    *html);
+
+void            yelp_html_select_all     (YelpHtml    *html);
+
+void            yelp_html_print          (YelpHtml    *html,
+					  YelpPrintInfo *info,
+					  gboolean preview,
+					  gint *npages);
+void            yelp_html_preview_end    (YelpHtml    *html);
+void            yelp_html_preview_navigate (YelpHtml *html,
+					    gint page_no);
+void            yelp_html_initialize     (void);
+
+G_END_DECLS
+
+#endif /* __YELP_HTML_H__ */
