@@ -120,6 +120,7 @@ struct _SearchContainer {
     gint         search_status;
     gchar *      elem_type;
     GSList *     elem_stack;
+    gfloat       score;
 };
 
 static void          search_pager_class_init      (YelpSearchPagerClass *klass);
@@ -260,8 +261,6 @@ search_pager_dispose (GObject *object)
 {
     YelpSearchPager *pager = YELP_SEARCH_PAGER (object);
 
-    g_free (pager->priv);
-
     G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
@@ -373,17 +372,6 @@ search_pager_process (YelpPager *pager)
 {
     d (g_print ("search_pager_process\n"));
 
-#ifdef ENABLE_BEAGLE
-    if (beagle_client == NULL) {
-	GError *error = NULL;
-	g_set_error (&error, YELP_ERROR, YELP_ERROR_PROC,
-		     _("Your search could not be processed. There "
-		       "is no connection to the beagle daemon."));
-	yelp_pager_error (YELP_PAGER (pager), error);
-	return FALSE;
-    }
-#endif /* ENABLE_BEAGLE */
-
     yelp_pager_set_state (pager, YELP_PAGER_STATE_PARSING);
     g_signal_emit_by_name (pager, "parse");
 
@@ -430,6 +418,15 @@ typedef struct
     xmlNode *node;
 } SnippetLocation;
 
+static void snippet_closed   (BeagleSnippetRequest  *request,
+			      SnippetLocation       *snippet_location);
+static void snippet_response (BeagleSnippetRequest  *request,
+			      BeagleSnippetResponse *response,
+			      SnippetLocation       *snippet_location);
+static void snippet_error    (BeagleSnippetRequest  *request,
+			      GError                *error,
+			      SnippetLocation       *snippet_location);
+
 static void
 snippet_closed (BeagleSnippetRequest *request, SnippetLocation *snippet_location)
 {
@@ -439,6 +436,17 @@ snippet_closed (BeagleSnippetRequest *request, SnippetLocation *snippet_location
 
     pager->priv->snippet_request_count --;
     check_finished (pager);
+
+    g_signal_handlers_disconnect_by_func (request,
+					  G_CALLBACK (snippet_response),
+					  snippet_location);
+    g_signal_handlers_disconnect_by_func (request,
+					  G_CALLBACK (snippet_error),
+					  snippet_location);
+    g_signal_handlers_disconnect_by_func (request,
+					  G_CALLBACK (snippet_closed),
+					  snippet_location);
+
     g_free (snippet_location);
     g_object_unref (request);
 }
@@ -454,7 +462,7 @@ snippet_response (BeagleSnippetRequest *request, BeagleSnippetResponse *response
 
     if (xml == NULL) {
 	d(g_print ("snippet_response empty\n"));
-	goto done;
+	return;
     }
     d(g_print ("snippet_response: %s\n", xml));
 
@@ -462,20 +470,17 @@ snippet_response (BeagleSnippetRequest *request, BeagleSnippetResponse *response
     snippet_doc = xmlParseDoc (BAD_CAST xmldoc);
     g_free (xmldoc);
     if (!snippet_doc)
-	goto done;
+	return;
     node = xmlDocGetRootElement (snippet_doc);
     xmlUnlinkNode (node);
     xmlAddChild (snippet_location->node, node);
     xmlFreeDoc (snippet_doc);
-    done:
-    snippet_closed (request, snippet_location);
 }
 
 static void
 snippet_error (BeagleSnippetRequest *request, GError *error, SnippetLocation *snippet_location)
 {
     d(g_print ("snippet_error\n"));
-    snippet_closed (request, snippet_location);
 }
 
 
@@ -552,7 +557,6 @@ finished_cb (BeagleQuery            *query,
     YelpSearchPagerPriv *priv = YELP_SEARCH_PAGER (pager)->priv;
 
     d(g_print ("finished_cb\n"));
-    g_object_unref (query);
 
     g_ptr_array_sort (priv->hits, compare_hits);
 
@@ -576,7 +580,7 @@ finished_cb (BeagleQuery            *query,
 
 	score = g_strdup_printf ("%f", beagle_hit_get_score (hit));
 	d(g_print ("%f\n", beagle_hit_get_score (hit)));
-	xmlSetProp (child, BAD_CAST "score", BAD_CAST score);
+	/*xmlSetProp (child, BAD_CAST "score", BAD_CAST score);*/
 	g_free (score);
 
 	priv->snippet_request_count ++;
@@ -602,6 +606,14 @@ finished_cb (BeagleQuery            *query,
 					  NULL);
     }
 
+    g_signal_handlers_disconnect_by_func (query,
+					  G_CALLBACK (hits_added_cb),
+					  pager);
+    g_signal_handlers_disconnect_by_func (query,
+					  G_CALLBACK (finished_cb),
+					  pager);
+    g_object_unref (query);
+
     g_ptr_array_foreach (priv->hits, (GFunc) beagle_hit_unref, NULL);
     g_ptr_array_free (priv->hits, TRUE);
     priv->hits = NULL;
@@ -625,39 +637,42 @@ search_pager_process_idle (YelpSearchPager *pager)
     xmlDocSetRootElement (priv->search_doc, priv->root);
 
 #ifdef ENABLE_BEAGLE
-    query = beagle_query_new ();
+    if (beagle_client != NULL) {
+	query = beagle_query_new ();
 
-    beagle_query_set_max_hits (query, 10000);
-    beagle_query_add_text (query, priv->search_terms);
-    beagle_query_add_mime_type (query, "text/html");
-    beagle_query_add_mime_type (query, "application/xhtml+xml");
-    beagle_query_add_mime_type (query, "text/xml");
-    beagle_query_add_mime_type (query, "application/xml");
-    beagle_query_add_mime_type (query, "application/docbook+xml");
-    beagle_query_add_mime_type (query, "text/x-docbook-entry");
+	beagle_query_set_max_hits (query, 10000);
+	beagle_query_add_text (query, priv->search_terms);
+	beagle_query_add_source (query, "documentation");
 
-    priv->hits = g_ptr_array_new ();
+	priv->hits = g_ptr_array_new ();
 
-    g_signal_connect (query, "hits-added",
-		      G_CALLBACK (hits_added_cb),
-		      pager);
+	g_signal_connect (query, "hits-added",
+			  G_CALLBACK (hits_added_cb),
+			  pager);
     
-    g_signal_connect (query, "finished",
-		      G_CALLBACK (finished_cb),
-		      pager);
+	g_signal_connect (query, "finished",
+			  G_CALLBACK (finished_cb),
+			  pager);
 	
-    beagle_client_send_request_async (beagle_client, BEAGLE_REQUEST (query), &error);
+	beagle_client_send_request_async (beagle_client, BEAGLE_REQUEST (query), &error);
 
-    if (error) {
-	d(g_print ("error: %s\n", error->message));
+	if (error) {
+	    d(g_print ("error: %s\n", error->message));
+	}
+
+	g_clear_error (&error);
+    } else {
+	g_warning ("beagled not running, using basic search support.");
     }
-
-    g_clear_error (&error);
 #endif /* ENABLE_BEAGLE */
 
-#ifndef ENABLE_BEAGLE
-    gtk_idle_add ((GtkFunction) slow_search_setup,
-		  pager);
+#ifdef ENABLE_BEAGLE
+    if (beagle_client == NULL) {
+#endif
+	gtk_idle_add ((GtkFunction) slow_search_setup,
+		      pager);
+#ifdef ENABLE_BEAGLE
+    }
 #endif
 
     return FALSE;
@@ -996,7 +1011,17 @@ void s_characters(void * data,
 		c->snippet = g_strndup (g_utf8_casefold ((gchar *) ch, len), 
 					len);
 		c->result_subsection = g_strdup (c->current_subsection);
-		
+
+		if (g_str_equal(c->elem_type, "primary")) {
+		    c->score = 1.0;
+		} else if (g_str_equal (c->elem_type, "secondary")) {
+		    c->score = 0.9;
+		} else if (g_str_equal (c->elem_type, "title") || 
+			   g_str_equal (c->elem_type, "titleabbrev")) {
+		    c->score = 0.8;
+		} else {
+		    c->score = 0.5;
+		}
 	    }
 	    i++;
 	    s_term = c->search_term[i];
@@ -1144,7 +1169,7 @@ slow_search_setup (YelpSearchPager *pager)
 	container->base_filename = g_strdup (realfname);
 	container->entities = g_hash_table_new (g_str_hash, g_str_equal);
 	container->doc_title = g_strdup ((gchar *) omf_title->stringval);
-
+	container->score=-1;
 
 	ptr = g_strrstr (container->base_filename, "/");
 
@@ -1152,7 +1177,7 @@ slow_search_setup (YelpSearchPager *pager)
 			    ptr - container->base_filename);
 	container->base_path = g_strdup (path);
 	container->search_term = 
-	    g_strsplit (g_utf8_casefold (pager->priv->search_terms, -1),
+	    g_strsplit (g_utf8_casefold (g_strstrip(pager->priv->search_terms), -1),
 			" ", -1);
 	container->search_status = NOT_SEARCHING;
 
@@ -1211,7 +1236,6 @@ slow_search_process (YelpSearchPager *pager)
 	    break;
 	}
     }
-
     /* Cleanup the container and delete it */
     g_free (c->current_subsection);
     g_free (c->result_subsection);
@@ -1347,7 +1371,8 @@ search_parse_result (YelpSearchPager *pager, SearchContainer *c)
 			     BAD_CAST "result", NULL);
     xmlSetProp (child, BAD_CAST "uri", BAD_CAST new_uri);
     xmlSetProp (child, BAD_CAST "title", BAD_CAST g_strstrip (c->doc_title));
-
+    xmlSetProp (child, BAD_CAST "score", 
+		BAD_CAST g_strdup_printf ("%f", c->score));
     /* Fix up the snippet to show the break_term in bold */
     xmldoc = g_strdup_printf ("<snippet>%s</snippet>",  
 			search_clean_snippet (c->snippet, c->search_term));
@@ -1371,7 +1396,7 @@ process_man_result (YelpSearchPager *pager, gchar *result, gchar **terms)
     gint i;
 
     for (i=0;split[i];i++) {
-	gchar ** line = g_strsplit (split[i], "-", 3); 
+	gchar ** line = g_strsplit (split[i], "-", 3);
 	gchar *filename = NULL;
 	gchar *desc = NULL;
 	xmlNode *child;
@@ -1388,8 +1413,10 @@ process_man_result (YelpSearchPager *pager, gchar *result, gchar **terms)
 	/* First is the filename */
 	before = g_strdup (g_strchomp (line[0]));
 	after = strstr (before, "(");
-	tmp = after;
-	tmp--;
+	tmp = after;	
+
+	while (!g_ascii_isspace(*tmp))
+	    tmp--;
 
 	title = g_strndup (before, tmp-before);
 
@@ -1408,6 +1435,8 @@ process_man_result (YelpSearchPager *pager, gchar *result, gchar **terms)
 	
 	xmlNewChild (child, NULL, BAD_CAST "snippet",
 		     BAD_CAST desc);
+	xmlNewChild (child, NULL, BAD_CAST "score",
+		     BAD_CAST "0.1");
 	g_strfreev (line);
 	g_free (before);
     }
@@ -1480,6 +1509,8 @@ process_info_result (YelpSearchPager *pager, gchar *result, gchar **terms)
 	
 	xmlNewChild (child, NULL, BAD_CAST "snippet",
 		     BAD_CAST desc);
+	xmlNewChild (child, NULL, BAD_CAST "score",
+		     BAD_CAST "0.05");
 	g_strfreev (line);
 	g_free (title);
     }
@@ -1492,19 +1523,23 @@ search_process_man (YelpSearchPager *pager, gchar **terms)
     gint i=0;
     for (i=0; terms[i]; i++) {
 	gchar *command;
-	gchar *stdout_str;
+	gchar *stdout_str = NULL;
 	gint exit_code;
-	command = g_strconcat("apropos ", terms[i], NULL);
-    
+	gchar *tmp = NULL;
+
+	tmp = g_strescape (terms[i], NULL);
+	tmp = g_strdelimit (tmp, "\'", '\'');
+	command = g_strconcat("apropos ", tmp, NULL);
+
 	if (g_spawn_command_line_sync (command, &stdout_str, NULL, 
 				       &exit_code, NULL) && exit_code == 0) {
 	    process_man_result (pager, stdout_str, terms);
 
 	}
+	g_free (tmp);
 	g_free (stdout_str);
 	g_free (command);
     }
-
     return;
 }
 
@@ -1514,16 +1549,21 @@ search_process_info (YelpSearchPager *pager, gchar **terms)
     gint i=0;
     for (i=0; terms[i]; i++) {
 	gchar *command;
-	gchar *stdout_str;
-	gchar *stderr_str;
+	gchar *stdout_str = NULL;
+	gchar *stderr_str = NULL;
+	gchar *tmp;
 	gint exit_code;
-	command = g_strconcat("info --apropos ", terms[i], NULL);
+	
+	tmp = g_strescape (terms[i], NULL);
+	tmp = g_strdelimit (tmp, "\'", '\'');
+	command = g_strconcat("info --apropos ", tmp, NULL);
     
 	if (g_spawn_command_line_sync (command, &stdout_str, &stderr_str, 
 				       &exit_code, NULL) && 
 	    stdout_str != NULL) {
 	    process_info_result (pager, stdout_str, terms);	    
 	}
+	g_free (tmp);
 	g_free (stdout_str);
 	g_free (stderr_str);
 	g_free (command);
