@@ -825,7 +825,7 @@ create_toc_from_index (YelpTocPager *pager, gchar *index_file)
 
     xmlXPathFreeContext (xpath);
     xmlXPathFreeObject (objsect);
-    xmlFree (manindex_xml);
+    xmlFreeDoc (manindex_xml);
     
     return 1;
 }
@@ -1139,12 +1139,12 @@ process_info_pending (YelpTocPager *pager)
 					       NULL);
 			    xmlNewNsProp (tmp, NULL, BAD_CAST "href", BAD_CAST fname);
 			    
-			    xmlNewChild (tmp, NULL, BAD_CAST "title",
+			    xmlNewTextChild (tmp, NULL, BAD_CAST "title",
 					 BAD_CAST part2);
-			    xmlNewChild (tmp, NULL, BAD_CAST "tooltip",
+			    xmlNewTextChild (tmp, NULL, BAD_CAST "tooltip",
 					 BAD_CAST tooltip);
 			    
-			    xmlNewChild (tmp, NULL, BAD_CAST "description",
+			    xmlNewTextChild (tmp, NULL, BAD_CAST "description",
 					 BAD_CAST desc);
 			}
 		    done:
@@ -1166,8 +1166,8 @@ process_info_pending (YelpTocPager *pager)
 			    xmlNewNsProp (new_node, NULL, BAD_CAST "id",
 					  BAD_CAST g_strdup_printf ("infosect%d", sectno));
 			    sectno++;
-			    xmlNewChild (new_node, NULL, BAD_CAST "title",
-					 BAD_CAST *ptr);
+			    xmlNewTextChild (new_node, NULL, BAD_CAST "title",
+					     BAD_CAST *ptr);
 			    g_hash_table_insert (categories, 
 						 g_strdup (*ptr),
 						 new_node);
