@@ -33,9 +33,7 @@
 #include <bonobo/bonobo-main.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomeui/gnome-stock-icons.h>
-#include <libgnome/gnome-url.h>
-#include <libgnome/gnome-program.h>
-#include <libgnome/gnome-config.h>
+#include <libgnome/libgnome.h>
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
 #include <string.h>
@@ -181,6 +179,7 @@ static void    window_go_previous_cb    (GtkAction *action, YelpWindow *window);
 static void    window_go_next_cb        (GtkAction *action, YelpWindow *window);
 static void    window_go_toc_cb         (GtkAction *action, YelpWindow *window);
 static void    window_add_bookmark_cb   (GtkAction *action, YelpWindow *window);
+static void    window_help_contents_cb  (GtkAction *action, YelpWindow *window);
 static void    window_about_cb          (GtkAction *action, YelpWindow *window);
 static void    window_copy_link_cb      (GtkAction *action, YelpWindow *window);
 static void    window_open_link_cb      (GtkAction *action, YelpWindow *window);
@@ -445,7 +444,11 @@ static const GtkActionEntry entries[] = {
       NULL,
       NULL,
       G_CALLBACK (window_copy_link_cb) },
-
+    { "Contents", GTK_STOCK_HELP,  
+      N_("_Contents"), 
+      "F1", 
+      N_("Help On this application"),
+      G_CALLBACK (window_help_contents_cb) },
     { "About", GNOME_STOCK_ABOUT,
       N_("_About"),
       NULL,
@@ -841,6 +844,7 @@ window_do_load (YelpWindow  *window,
 		gchar       *frag_id)
 {
     GtkAction      *action;
+    GtkAction      *about;
     GError         *error = NULL;
     gchar          *uri;
 
@@ -851,10 +855,11 @@ window_do_load (YelpWindow  *window,
 
     action = gtk_action_group_get_action (window->priv->action_group, 
 					  "PrintDocument");
-    g_object_set (G_OBJECT (action),
-		  "sensitive",
-		  FALSE,
-		  NULL);
+    g_object_set (G_OBJECT (action), "sensitive", FALSE, NULL);
+
+    about  = gtk_action_group_get_action (window->priv->action_group,
+                                          "AboutDocument");
+    g_object_set (G_OBJECT (about),  "sensitive", FALSE, NULL);
     
     switch (yelp_doc_info_get_type (doc_info)) {
     case YELP_DOC_TYPE_MAN:
@@ -878,10 +883,8 @@ window_do_load (YelpWindow  *window,
 #endif
 
     case YELP_DOC_TYPE_DOCBOOK_XML:
-	g_object_set (G_OBJECT (action),
-		      "sensitive",
-		      TRUE,
-		      NULL);
+	g_object_set (G_OBJECT (action), "sensitive", TRUE, NULL);
+	g_object_set (G_OBJECT (about),  "sensitive", TRUE, NULL);
     case YELP_DOC_TYPE_TOC:
 	window_do_load_pager (window, doc_info, frag_id);
 	break;
@@ -1784,10 +1787,19 @@ pager_page_cb (YelpPager *pager,
     if (yelp_pager_page_contains_frag (pager,
 				       page_id,
 				       window->priv->current_frag)) {
-	window_disconnect (window);
-
 	page = (YelpPage *) yelp_pager_get_page (pager, page_id);
-	window_handle_page (window, page);
+
+	/* now that yelp automatically inserts the id="index" attribute
+	 * on the root element of a document, the _contains_frag function
+	 * is no longer a good indication of whether a section exists.
+	 * Therefore if the returned page is NULL, then the stylesheets
+	 * were not able to create a "page" from this document through the
+	 * exsl:document extension (see yelp_xslt_document())
+	 * -Brent Smith, 1/4/2006 */
+	if (page) {
+	    window_disconnect (window);
+	    window_handle_page (window, page);
+	}
     }
 }
 
@@ -2632,16 +2644,31 @@ window_copy_mail_cb (GtkAction *action, YelpWindow *window)
     g_strfreev(split_string);
 }
 
+static void
+window_help_contents_cb (GtkAction *action, YelpWindow *window)
+{
+    /* Since we are already running, and are calling ourselves,
+     * we can make this function easy by just creating a new window
+     * and avoiding calling gnome_help_display_desktop
+     */
+    g_signal_emit (window, signals[NEW_WINDOW_REQUESTED], 0, 
+                   "ghelp:user-guide#yelp");
+}
+
 static void
 window_about_cb (GtkAction *action, YelpWindow *window)
 {
     const gchar *copyright =
 	"Copyright © 2001-2003 Mikael Hallendal\n"
-	"Copyright © 2003-2005 Shaun McCance";
+	"Copyright © 2003-2005 Shaun McCance\n"
+	"Copyright © 2005-2006 Don Scorgie\n"
+	"Copyright © 2005-2006 Brent Smith";
     const gchar *authors[] = { 
 	"Mikael Hallendal <micke@imendio.com>",
 	"Alexander Larsson <alexl@redhat.com>",
 	"Shaun McCance <shaunm@gnome.org>",
+	"Don Scorgie <DonScorgie@Blueyonder.co.uk>",
+	"Brent Smith <gnome@nextreality.net>",
 	NULL
     };
     /* Note to translators: put here your name (and address) so it
